@@ -38,6 +38,10 @@ $key = q/load/;
 $external_labels{$key} = "$URL/" . q|node4.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/analysis/;
+$external_labels{$key} = "$URL/" . q|node6.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/Actions_for_controlling_scheduling_of_URLs/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
@@ -238,6 +242,10 @@ $key = q/httpProxy/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/relTextPlugin/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/doCheckRecord/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
@@ -386,6 +394,10 @@ $key = q/gory/;
 $external_labels{$key} = "$URL/" . q|node11.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/SVMmodel/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/cite_Yang_99/;
 $external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
@@ -398,6 +410,10 @@ $key = q/_get/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/analysePlugin/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/new_/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
@@ -406,14 +422,14 @@ $key = q/gettingstarted/;
 $external_labels{$key} = "$URL/" . q|node4.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/exclude/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/LICENSE/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/exclude/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/cite_GolubChall/;
 $external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
@@ -506,11 +522,11 @@ $key = q/InstTest/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/topic_reset_topic_rewind_topic_add_topic_get_/;
+$key = q/Actions_loading_or_recycling_URLs_for_crawling/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/Actions_loading_or_recycling_URLs_for_crawling/;
+$key = q/topic_reset_topic_rewind_topic_add_topic_get_/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
@@ -530,14 +546,14 @@ $key = q/debian/;
 $external_labels{$key} = "$URL/" . q|node4.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/_rewind_/;
-$external_labels{$key} = "$URL/" . q|node16.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/WaitIntervalHarvesterLockSuccess/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/_rewind_/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/cite_Svenonius_2000/;
 $external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
@@ -566,7 +582,7 @@ $noresave{$key} = "$nosave";
 
 
 $key = q/maxUrlLength/;
-$external_latex_labels{$key} = q|9.1.14|; 
+$external_latex_labels{$key} = q|9.1.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_for_deleting_records/;
@@ -574,7 +590,7 @@ $external_latex_labels{$key} = q|A.5.7|;
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockNotFound/;
-$external_latex_labels{$key} = q|9.1.27|; 
+$external_latex_labels{$key} = q|9.1.30|; 
 $noresave{$key} = "$nosave";
 
 $key = q/appendix/;
@@ -582,11 +598,11 @@ $external_latex_labels{$key} = q|A|;
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalExpirationGuaranteed/;
-$external_latex_labels{$key} = q|9.1.26|; 
+$external_latex_labels{$key} = q|9.1.29|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Password/;
-$external_latex_labels{$key} = q|9.1.18|; 
+$external_latex_labels{$key} = q|9.1.19|; 
 $noresave{$key} = "$nosave";
 
 $key = q/crawlspeed/;
@@ -618,19 +634,19 @@ $external_latex_labels{$key} = q|2|;
 $noresave{$key} = "$nosave";
 
 $key = q/Loglev/;
-$external_latex_labels{$key} = q|9.1.13|; 
+$external_latex_labels{$key} = q|9.1.14|; 
 $noresave{$key} = "$nosave";
 
 $key = q/HarvesterMaxMissions/;
-$external_latex_labels{$key} = q|9.1.9|; 
+$external_latex_labels{$key} = q|9.1.10|; 
 $noresave{$key} = "$nosave";
 
 $key = q/url_remove_url_reset_url_rewind_url_add_url_get_/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/doOAI/;
-$external_latex_labels{$key} = q|9.1.7|; 
+$external_latex_labels{$key} = q|9.1.8|; 
 $noresave{$key} = "$nosave";
 
 $key = q/extmods/;
@@ -641,8 +657,12 @@ $key = q/Action_all/;
 $external_latex_labels{$key} = q|A.5.7|; 
 $noresave{$key} = "$nosave";
 
+$key = q/analysis/;
+$external_latex_labels{$key} = q|4.8|; 
+$noresave{$key} = "$nosave";
+
 $key = q/Actions_for_controlling_scheduling_of_URLs/;
-$external_latex_labels{$key} = q|A.5.1|; 
+$external_latex_labels{$key} = q|A.5.2|; 
 $noresave{$key} = "$nosave";
 
 $key = q/comp/;
@@ -650,15 +670,15 @@ $external_latex_labels{$key} = q|7|;
 $noresave{$key} = "$nosave";
 
 $key = q/AutoRecycleLinks/;
-$external_latex_labels{$key} = q|9.1.1|; 
+$external_latex_labels{$key} = q|9.1.2|; 
 $noresave{$key} = "$nosave";
 
 $key = q/heading_reset_heading_rewind_heading_add_heading_get_/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockUnavailable/;
-$external_latex_labels{$key} = q|9.1.31|; 
+$external_latex_labels{$key} = q|9.1.34|; 
 $noresave{$key} = "$nosave";
 
 $key = q/crawl/;
@@ -666,15 +686,15 @@ $external_latex_labels{$key} = q|3|;
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_starting_killing_crawlers/;
-$external_latex_labels{$key} = q|A.5.1|; 
+$external_latex_labels{$key} = q|A.5.2|; 
 $noresave{$key} = "$nosave";
 
 $key = q/SummaryLength/;
-$external_latex_labels{$key} = q|9.1.21|; 
+$external_latex_labels{$key} = q|9.1.23|; 
 $noresave{$key} = "$nosave";
 
 $key = q/SdqRetries/;
-$external_latex_labels{$key} = q|9.1.20|; 
+$external_latex_labels{$key} = q|9.1.22|; 
 $noresave{$key} = "$nosave";
 
 $key = q/urlfilt/;
@@ -694,11 +714,11 @@ $external_latex_labels{$key} = q|1|;
 $noresave{$key} = "$nosave";
 
 $key = q/xmeta_reset_xmeta_rewind_xmeta_add_xmeta_get_/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/METHODS/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/slowcrawl/;
@@ -722,11 +742,11 @@ $external_latex_labels{$key} = q|2|;
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalRrdLockSuccess/;
-$external_latex_labels{$key} = q|9.1.35|; 
+$external_latex_labels{$key} = q|9.1.38|; 
 $noresave{$key} = "$nosave";
 
 $key = q/NAME/;
-$external_latex_labels{$key} = q|A.5.17|; 
+$external_latex_labels{$key} = q|A.5.20|; 
 $noresave{$key} = "$nosave";
 
 $key = q/faq/;
@@ -734,15 +754,15 @@ $external_latex_labels{$key} = q|8|;
 $noresave{$key} = "$nosave";
 
 $key = q/useTidy/;
-$external_latex_labels{$key} = q|9.1.25|; 
+$external_latex_labels{$key} = q|9.1.28|; 
 $noresave{$key} = "$nosave";
 
 $key = q/OPTIONS_AND_ARGUMENTS/;
-$external_latex_labels{$key} = q|A.5.7|; 
+$external_latex_labels{$key} = q|A.5.8|; 
 $noresave{$key} = "$nosave";
 
 $key = q/robot_reset_robot_rewind_robot_add_robot_get_/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/std/;
@@ -750,23 +770,23 @@ $external_latex_labels{$key} = q|4.5.4|;
 $noresave{$key} = "$nosave";
 
 $key = q/configDir/;
-$external_latex_labels{$key} = q|9.1.4|; 
+$external_latex_labels{$key} = q|9.1.5|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Misc_actions/;
-$external_latex_labels{$key} = q|A.5.1|; 
+$external_latex_labels{$key} = q|A.5.2|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_exporting_link_data/;
-$external_latex_labels{$key} = q|A.5.4|; 
+$external_latex_labels{$key} = q|A.5.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockRobotRules/;
-$external_latex_labels{$key} = q|9.1.29|; 
+$external_latex_labels{$key} = q|9.1.32|; 
 $noresave{$key} = "$nosave";
 
 $key = q/INTRODUCTION/;
-$external_latex_labels{$key} = q|A.5.17|; 
+$external_latex_labels{$key} = q|A.5.10|; 
 $noresave{$key} = "$nosave";
 
 $key = q/gory/;
@@ -774,23 +794,31 @@ $external_latex_labels{$key} = q|II|;
 $noresave{$key} = "$nosave";
 
 $key = q/MySQLhandle/;
-$external_latex_labels{$key} = q|9.1.16|; 
+$external_latex_labels{$key} = q|9.1.17|; 
+$noresave{$key} = "$nosave";
+
+$key = q/SVMmodel/;
+$external_latex_labels{$key} = q|9.1.24|; 
+$noresave{$key} = "$nosave";
+
+$key = q/analysePlugin/;
+$external_latex_labels{$key} = q|9.1.1|; 
 $noresave{$key} = "$nosave";
 
 $key = q/SYNOPSIS/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/_get/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/meta_reset_meta_rewind_meta_add_meta_get_/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/new_/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/gettingstarted/;
@@ -802,11 +830,19 @@ $external_latex_labels{$key} = q|9.2.4|;
 $noresave{$key} = "$nosave";
 
 $key = q/LICENSE/;
-$external_latex_labels{$key} = q|A.5.10|; 
+$external_latex_labels{$key} = q|A.5.18|; 
 $noresave{$key} = "$nosave";
 
 $key = q/UserAgentFollowRedirects/;
-$external_latex_labels{$key} = q|9.1.23|; 
+$external_latex_labels{$key} = q|9.1.26|; 
+$noresave{$key} = "$nosave";
+
+$key = q/Operator-Email/;
+$external_latex_labels{$key} = q|9.1.18|; 
+$noresave{$key} = "$nosave";
+
+$key = q/domainfocus/;
+$external_latex_labels{$key} = q|2.4.2|; 
 $noresave{$key} = "$nosave";
 
 $key = q/manpages/;
@@ -817,16 +853,8 @@ $key = q/sqlstruct/;
 $external_latex_labels{$key} = q|A.4|; 
 $noresave{$key} = "$nosave";
 
-$key = q/domainfocus/;
-$external_latex_labels{$key} = q|2.4.2|; 
-$noresave{$key} = "$nosave";
-
-$key = q/Operator-Email/;
-$external_latex_labels{$key} = q|9.1.17|; 
-$noresave{$key} = "$nosave";
-
 $key = q/_add/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/autoclass/;
@@ -834,11 +862,11 @@ $external_latex_labels{$key} = q|4.5|;
 $noresave{$key} = "$nosave";
 
 $key = q/XXX_val_/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/MySQLdatabase/;
-$external_latex_labels{$key} = q|9.1.15|; 
+$external_latex_labels{$key} = q|9.1.16|; 
 $noresave{$key} = "$nosave";
 
 $key = q/sched/;
@@ -846,19 +874,19 @@ $external_latex_labels{$key} = q|4.4|;
 $noresave{$key} = "$nosave";
 
 $key = q/ZebraHost/;
-$external_latex_labels{$key} = q|9.1.37|; 
+$external_latex_labels{$key} = q|9.1.40|; 
 $noresave{$key} = "$nosave";
 
 $key = q/classifyPlugIn/;
-$external_latex_labels{$key} = q|9.1.3|; 
+$external_latex_labels{$key} = q|9.1.4|; 
 $noresave{$key} = "$nosave";
 
 $key = q/SEE_ALSO/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/saveHTML/;
-$external_latex_labels{$key} = q|9.1.19|; 
+$external_latex_labels{$key} = q|9.1.21|; 
 $noresave{$key} = "$nosave";
 
 $key = q/configvars/;
@@ -866,7 +894,7 @@ $external_latex_labels{$key} = q|9|;
 $noresave{$key} = "$nosave";
 
 $key = q/AUTHOR/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.20|; 
 $noresave{$key} = "$nosave";
 
 $key = q/moddep/;
@@ -874,19 +902,19 @@ $external_latex_labels{$key} = q|10|;
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalRrdLockNotFound/;
-$external_latex_labels{$key} = q|9.1.34|; 
+$external_latex_labels{$key} = q|9.1.37|; 
 $noresave{$key} = "$nosave";
 
 $key = q/serveralias/;
 $external_latex_labels{$key} = q|9.2.5|; 
 $noresave{$key} = "$nosave";
 
-$key = q/WaitIntervalRrdLockDefault/;
-$external_latex_labels{$key} = q|9.1.33|; 
+$key = q/HarvestRetries/;
+$external_latex_labels{$key} = q|9.1.11|; 
 $noresave{$key} = "$nosave";
 
-$key = q/HarvestRetries/;
-$external_latex_labels{$key} = q|9.1.10|; 
+$key = q/WaitIntervalRrdLockDefault/;
+$external_latex_labels{$key} = q|9.1.36|; 
 $noresave{$key} = "$nosave";
 
 $key = q/overview/;
@@ -894,35 +922,35 @@ $external_latex_labels{$key} = q|1|;
 $noresave{$key} = "$nosave";
 
 $key = q/UAtimeout/;
-$external_latex_labels{$key} = q|9.1.22|; 
+$external_latex_labels{$key} = q|9.1.25|; 
 $noresave{$key} = "$nosave";
 
 $key = q/link_reset_link_rewind_link_add_link_get_/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/UserAgentGetIfModifiedSince/;
-$external_latex_labels{$key} = q|9.1.24|; 
+$external_latex_labels{$key} = q|9.1.27|; 
 $noresave{$key} = "$nosave";
 
 $key = q/DESCRIPTION/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.20|; 
 $noresave{$key} = "$nosave";
 
 $key = q/baseConfigDir/;
-$external_latex_labels{$key} = q|9.1.2|; 
+$external_latex_labels{$key} = q|9.1.3|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockNotModified/;
-$external_latex_labels{$key} = q|9.1.28|; 
+$external_latex_labels{$key} = q|9.1.31|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHost/;
-$external_latex_labels{$key} = q|9.1.32|; 
+$external_latex_labels{$key} = q|9.1.35|; 
 $noresave{$key} = "$nosave";
 
 $key = q/COPYRIGHT_AND_LICENSE/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.20|; 
 $noresave{$key} = "$nosave";
 
 $key = q/distr/;
@@ -938,7 +966,7 @@ $external_latex_labels{$key} = q|A.2|;
 $noresave{$key} = "$nosave";
 
 $key = q/_reset_/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/termlist/;
@@ -946,7 +974,7 @@ $external_latex_labels{$key} = q|4.5.1|;
 $noresave{$key} = "$nosave";
 
 $key = q/doAnalyse/;
-$external_latex_labels{$key} = q|9.1.5|; 
+$external_latex_labels{$key} = q|9.1.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/InstTest/;
@@ -954,7 +982,7 @@ $external_latex_labels{$key} = q|A.1|;
 $noresave{$key} = "$nosave";
 
 $key = q/BUGS/;
-$external_latex_labels{$key} = q|A.5.17|; 
+$external_latex_labels{$key} = q|A.5.10|; 
 $noresave{$key} = "$nosave";
 
 $key = q/topicfilter/;
@@ -969,24 +997,24 @@ $key = q/binext/;
 $external_latex_labels{$key} = q|9.2.2|; 
 $noresave{$key} = "$nosave";
 
-$key = q/Actions_loading_or_recycling_URLs_for_crawling/;
-$external_latex_labels{$key} = q|A.5.1|; 
-$noresave{$key} = "$nosave";
-
 $key = q/EXAMPLES/;
 $external_latex_labels{$key} = q|A.5.7|; 
 $noresave{$key} = "$nosave";
 
-$key = q/AUTHOR_Anders_Ardo/;
-$external_latex_labels{$key} = q|A.5.10|; 
+$key = q/Actions_loading_or_recycling_URLs_for_crawling/;
+$external_latex_labels{$key} = q|A.5.2|; 
 $noresave{$key} = "$nosave";
 
 $key = q/topic_reset_topic_rewind_topic_add_topic_get_/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
+$noresave{$key} = "$nosave";
+
+$key = q/AUTHOR_Anders_Ardo/;
+$external_latex_labels{$key} = q|A.5.18|; 
 $noresave{$key} = "$nosave";
 
 $key = q/LogHandle/;
-$external_latex_labels{$key} = q|9.1.12|; 
+$external_latex_labels{$key} = q|9.1.13|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_for_handling_server_aliases/;
@@ -994,31 +1022,35 @@ $external_latex_labels{$key} = q|A.5.7|;
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalSchedulerGetJcf/;
-$external_latex_labels{$key} = q|9.1.36|; 
+$external_latex_labels{$key} = q|9.1.39|; 
 $noresave{$key} = "$nosave";
 
 $key = q/httpProxy/;
-$external_latex_labels{$key} = q|9.1.11|; 
+$external_latex_labels{$key} = q|9.1.12|; 
 $noresave{$key} = "$nosave";
 
 $key = q/debian/;
 $external_latex_labels{$key} = q|2.1.3|; 
 $noresave{$key} = "$nosave";
 
+$key = q/relTextPlugin/;
+$external_latex_labels{$key} = q|9.1.20|; 
+$noresave{$key} = "$nosave";
+
 $key = q/doCheckRecord/;
-$external_latex_labels{$key} = q|9.1.6|; 
+$external_latex_labels{$key} = q|9.1.7|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockSuccess/;
-$external_latex_labels{$key} = q|9.1.30|; 
+$external_latex_labels{$key} = q|9.1.33|; 
 $noresave{$key} = "$nosave";
 
 $key = q/_rewind_/;
-$external_latex_labels{$key} = q|A.5.16|; 
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/extractLinksFromText/;
-$external_latex_labels{$key} = q|9.1.8|; 
+$external_latex_labels{$key} = q|9.1.9|; 
 $noresave{$key} = "$nosave";
 
 $key = q/conffiles/;
@@ -1026,7 +1058,7 @@ $external_latex_labels{$key} = q|A.3|;
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_calculating_variants_of_PageRank/;
-$external_latex_labels{$key} = q|A.5.4|; 
+$external_latex_labels{$key} = q|A.5.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/config/;
